@@ -1,4 +1,4 @@
-# pylint: disable=C0415, W0603, W1508
+# pylint: disable=C0415, W0603, W1508, R0913
 #  Drakkar-Software OctoBot-Commons
 #  Copyright (c) Drakkar-Software, All rights reserved.
 #
@@ -16,20 +16,12 @@
 #  License along with this library.
 
 import logging
-import os
 
 import octobot_commons.timestamp_util as timestamp_util
 
 LOG_DATABASE = "log_db"
 LOG_NEW_ERRORS_COUNT = "log_new_errors_count"
 
-DISABLE_SENTRY = os.getenv("DISABLE_SENTRY", None)
-SENTRY_URL = os.getenv("SENTRY_URL", "o563994.ingest.sentry.io")
-SENTRY_KEY = os.getenv("SENTRY_KEY", "e0847deba5334a3aa668c461ed44c218")
-SENTRY_PROJECT = os.getenv("SENTRY_PROJECT", "5704514")
-SENTRY_RATE = os.getenv("SENTRY_RATE", 1.0)
-SENTRY_ENV = os.getenv("SENTRY_ENV", "production")
-
 BACKTESTING_NEW_ERRORS_COUNT: str = "log_backtesting_errors_count"
 
 logs_database = {
@@ -47,6 +39,13 @@ ERROR_PUBLICATION_ENABLED = True
 SHOULD_PUBLISH_LOGS_WHEN_RE_ENABLED = False
 
 
+def _default_callback(*_, **__):
+    pass
+
+
+_ERROR_CALLBACK = _default_callback
+
+
 def set_global_logger_level(level) -> None:
     """
     Set the global logger level
@@ -147,8 +146,6 @@ class BotLogger:
     def __init__(self, logger_name):
         self.logger_name = logger_name
         self.logger = logging.getLogger(logger_name)
-        # Disable until performance impact is measured
-        # self.setup_sentry_logging()
 
     def debug(self, message, *args, **kwargs) -> None:
         """
@@ -174,13 +171,15 @@ class BotLogger:
         self.logger.warning(message, *args, **kwargs)
         self._publish_log_if_necessary(message, logging.WARNING)
 
-    def error(self, message, *args, **kwargs) -> None:
+    def error(self, message, *args, skip_post_callback=False, **kwargs) -> None:
         """
         Called for an error log
         :param message: the log message
+        :param skip_post_callback: when True, the error callback wont be called
         """
         self.logger.error(message, *args, **kwargs)
         self._publish_log_if_necessary(message, logging.ERROR)
+        self._post_callback_if_necessary(None, message, skip_post_callback)
 
     def exception(
         self,
@@ -188,6 +187,7 @@ class BotLogger:
         publish_error_if_necessary=True,
         error_message=None,
         include_exception_name=True,
+        skip_post_callback=False,
         **kwargs,
     ) -> None:
         """
@@ -196,6 +196,7 @@ class BotLogger:
         :param publish_error_if_necessary: if the error should be published
         :param error_message: the log message
         :param include_exception_name: when True adds the __class__.__name__ of the exception at the end of the message
+        :param skip_post_callback: when True, the error callback wont be called
         """
         self.logger.exception(exception, **kwargs)
         if publish_error_if_necessary:
@@ -204,7 +205,8 @@ class BotLogger:
                 message = exception if str(exception) else exception.__class__.__name__
             elif include_exception_name:
                 message = f"{message} ({exception.__class__.__name__})"
-            self.error(message)
+            self.error(message, skip_post_callback=True)
+        self._post_callback_if_necessary(exception, error_message, skip_post_callback)
 
     def critical(self, message, *args, **kwargs) -> None:
         """
@@ -254,31 +256,19 @@ class BotLogger:
             call_notifiers=ERROR_PUBLICATION_ENABLED,
         )
 
-    def setup_sentry_logging(self):
+    @staticmethod
+    def register_error_callback(callback):
         """
-        Setup sentry logging if SENTRY_ENABLED and OctoBot version is importable
+        :param callback: the callback to be called upon errors and exceptions
+        Register callback as the ERROR_CALLBACK
         """
-        if DISABLE_SENTRY is None:
-            try:
-                from octobot.constants import VERSION
-                import sentry_sdk
-                import sentry_sdk.integrations.logging as sentry_logging
+        global _ERROR_CALLBACK
+        _ERROR_CALLBACK = callback
 
-                sentry_sdk.init(
-                    f"https://{SENTRY_KEY}@{SENTRY_URL}/{SENTRY_PROJECT}",
-                    traces_sample_rate=SENTRY_RATE,
-                    release=VERSION,
-                    environment=SENTRY_ENV,
-                    integrations=[
-                        sentry_logging.LoggingIntegration(
-                            level=logging.ERROR, event_level=logging.ERROR
-                        )
-                    ],
-                )
-            except ImportError:
-                self.logger.debug(
-                    "Failed to start sentry : can't import OctoBot version"
-                )
+    @staticmethod
+    def _post_callback_if_necessary(exception, error_message, skip_post_callback):
+        if not skip_post_callback:
+            _ERROR_CALLBACK(exception, error_message)
 
 
 def get_backtesting_errors_count() -> int:
